@@ -21,7 +21,7 @@ Usage::
     describe_notifications_for_budget_paginator: DescribeNotificationsForBudgetPaginator = client.get_paginator("describe_notifications_for_budget")
     describe_subscribers_for_notification_paginator: DescribeSubscribersForNotificationPaginator = client.get_paginator("describe_subscribers_for_notification")
 """
-from mypy_boto3_budgets.client import BudgetsClient as Client, BudgetsClient
+from mypy_boto3_budgets.client import BudgetsClient, BudgetsClient as Client
 from mypy_boto3_budgets.paginator import (
     DescribeBudgetsPaginator,
     DescribeNotificationsForBudgetPaginator,
